| Name | Modified | Size | Downloads / Week |
|---|---|---|---|
| Parent folder | |||
| vx-x86_64-apple-darwin.tar.gz | 2026-10-08 | 39.2 MB | |
| vx-aarch64-apple-darwin.tar.gz | 2026-10-08 | 36.9 MB | |
| vx-aarch64-unknown-linux-gnu.tar.gz | 2026-10-08 | 35.1 MB | |
| vx-x86_64-unknown-linux-gnu.tar.gz | 2026-10-08 | 37.4 MB | |
| 0.88.0 source code.tar.gz | 2026-10-08 | 6.2 MB | |
| 0.88.0 source code.zip | 2026-10-08 | 8.6 MB | |
| README.md | 2026-10-08 | 5.6 kB | |
| Totals: 7 Items | 163.3 MB | 0 | |
Important breaks
None
Changes
β οΈ Breaks
- Speed up scalar construction, stats reads and aggregate partial merging (#10326) @robert3005
- break(arrow): add export options and allow skipping view buffer compaction (#10220) @lorenzhs
- Blocked
BitPacked: store block offsets as a child (#10004) @mhk197 - Delta validity is a top level child (#9970) @robert3005
- Move users of map_each_with_validity and map_each_in_place to lane kernels and remove those methods (#10139) @robert3005
π§ Deprecation
- Remove usages of
null_as_false(#10124) @myrrc
β¨ Features
- Add support for reading vortex files through native python readers (#10097) @robert3005
- duckdb: don't execute validity in exporters (#10376) @myrrc
- Blocked
BitPacked: encode blocked bitwidths (#10203) @mhk197 - AllFalse early exit (#10303) @myrrc
- Scan protocol traits (#10047) @joseph-isaacs
- Add combine_chunks option to Python Arrow export (#10279) @robert3005
- feat(python): support integer column indices in read_url projection (#10287) @jackylee-ch
π Performance
- Bool take doesn't fill_null validity (#10383) @myrrc
- perf(array): expand FixedSizeList filter masks directly into a bitmap (#10274) @robert3005
- Make opening a Vortex file with a cached footer cheaper (#10358) @joseph-isaacs
- perf: classify canonical arrays by concrete vtable (#10238) @joseph-isaacs
- Add OnPair take kernel that shares the pair dictionary (#10363) @joseph-isaacs
- perf(arrow): preserve source nullability during export (#10365) @joseph-isaacs
- Read integer validity a word per chunk, and fill nulls for runs (#10342) @joseph-isaacs
- Read VarBin UTF-8 RowFn inputs through their offsets (#10340) @connortsui20
- Execute FSST iteratively (#10209) @joseph-isaacs
- perf(array): avoid errors when comparison kernels decline arithmetic (#10301) @connortsui20
- Faster ScalarFnArray creation, lazy ArrayStats (#10329) @myrrc
- perf(buffer): use fearless_simd for popcount (#10327) @joseph-isaacs
- Initialise ArrayParts directly with provided slots (#10072) @robert3005
- Execute OnPair iteratively (#10210) @joseph-isaacs
- perf(compressor): detect constant primitives before generating stats (#10043) @robert3005
- perf: vectorize small u8 table take with AVX2 (#9572) @joseph-isaacs
- perf: vectorize small u8 table take with NEON (#9571) @joseph-isaacs
- Optimise min/max computation for VarBinView arrays (#9740) @robert3005
- Execute DecimalByteParts iteratively (#10207) @joseph-isaacs
- Execute RunEnd iteratively (#10206) @joseph-isaacs
- perf(zstd): reuse one decompression context per thread (#10270) @joseph-isaacs
- feat: add between kernel for DecimalByteParts (#10152) @joseph-isaacs
- python: release the GIL only around expensive work (#10280) @robert3005
- Convert trivial filters into slices during reduction, MaskValues::last uses BitBuffer::last_set_index (#9831) @robert3005
- perf(array): forward probe_scalar through pass-through encodings (#9905) @joseph-isaacs
- Perform validation and null view replacement in two passes (#10148) @robert3005